package com.mathieubolla.externalui.uibuilder;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class Line {
	private List<Element> elements = new ArrayList<Element>();
	private final int blockCount;
	
	public Line(int blockCount, Element... elements) {
		this.blockCount = blockCount;
		this.elements.addAll(Arrays.asList(elements));
	}
	
	public static Line line(int blockCount, Element... givenElements) {
		return new Line(blockCount, givenElements);
	}
	
	public String render(int blockSizeInPercent) {
		StringBuilder builder = new StringBuilder("<div style=\"width:100%; height:"+blockSizeInPercent+"%; background-color:#EEEEEE;border-radius:0.5em;border-width:1px;border-color:#555555\">");
		int totalBlocks = countBlocks();

		for (Element element : elements) {
			builder.append(element.render(element.getBlockCount() * 100 / totalBlocks));
		}
		
		return builder.append("</div>").toString();
	}
	
	public int getBlockCount() {
		return blockCount;
	}
	
	private int countBlocks() {
		int blocks = 0;
		for(Element element:elements) {
			blocks += element.getBlockCount();
		}
		return blocks;
	}
}
