package com.mathieubolla.externalui.uibuilder;

import static java.util.Arrays.asList;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.io.IOUtils;

import com.mathieubolla.externalui.utils.StreamProvider;

public class UIBuilder implements StreamProvider {
	List<Line> lines = new ArrayList<Line>();
	
	public UIBuilder(Line... givenLines) {
		lines.addAll(asList(givenLines));
	}

	@Override
	public InputStream get() {
		try {
			String headers = IOUtils.toString(this.getClass().getResourceAsStream("/headers.txt"));
			String footers = IOUtils.toString(this.getClass().getResourceAsStream("/footers.txt"));
			return new ByteArrayInputStream((headers+render()+footers).getBytes(Charset.forName("UTF-8")));
		} catch (IOException e) {
			throw new RuntimeException("Can't build UI", e);
		}
	}
	
	private String render() {
		StringBuilder builder = new StringBuilder();
		int totalBlocks = countBlocks();
		
		for (Line line: lines) {
			builder.append(line.render(line.getBlockCount() * 100 / totalBlocks));
		}
		return builder.toString();
	}

	public static UIBuilder with(Line... givenLines) {
		return new UIBuilder(givenLines);
	}
	
	private int countBlocks() {
		int blocks = 0;
		for(Line line:lines) {
			blocks += line.getBlockCount();
		}
		return blocks;
	}
}